@@ -6,7 +6,7 @@ use Data::Recursive::Encode;
 use parent qw/Exporter/;
 our @EXPORT = qw/eDumper Dumper/;
 
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 
 our $ENCODING = '';
 
@@ -16,6 +16,7 @@ sub _dump {
 }
 
 sub eDumper {
+    local $Data::Recursive::Encode::DO_NOT_PROCESS_NUMERIC_VALUE = 1;
     my @args;
     for my $arg (@_) {
         push @args, Data::Recursive::Encode->encode($ENCODING || 'utf8', $arg);
@@ -104,8 +105,6 @@ Dai Okabayashi E<lt>bayashi@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<edumper>
-
 L<Data::Dumper>
 
 
